package JTable_2;


/**
 * Ist die Datenbasis - das Modell - fr die Tabelle
 * 
 * @author      Florian
 * @version     Kapitel 13
 */
import javax.swing.table.TableModel;
import javax.swing.event.TableModelListener;

public class Planetenverwaltung implements TableModel
{
    /**
     * Die Datenbasis - ein Array, das die neun Planeten speichert
     */
    private Planet[] datenbasis = 
    {
        new Planet("Merkur", 87.99), 
        new Planet("Venus", 224.7), 
        new Planet("Erde", 365.2), 
        new Planet("Mars", 687), 
        new Planet("Jupiter", 4332), 
        new Planet("Saturn", 10760), 
        new Planet("Uranus", 30680), 
        new Planet("Neptun", 59900), 
        new Planet("Pluto", 90800)         
    };
    
    /**
     * Listener fr nderungen an der Datenbasis
     */
    private TableModelListener listener = null;

    /**
     * Gibt die Anzahl der Datenstze - Zeilen - zurck
     * @return int - Anzahl der Zeilen
     */
    public int getRowCount()
    { 
        return datenbasis.length;
    }

    /**
     * Gibt die Anzahl der Spalten zurck
     * @return int - Anzahl der Spalten
     */
    public int getColumnCount()
    { 
        return 2;
    }

    /**
     * gibt die berschrift einer bestimmten Spalten zurck
     * @param int die gesuchte Spalte
     * @return String - Name der berschrift
     */
    public String getColumnName(int columnIndex)
    { 
        switch(columnIndex)
        {
            case 0:     return "Planet"; 
            default:    return "Umlaufzeit";            
        }
    }

    /**
     * gibt zurck, ob die Zelle editierbar ist oder nicht 
     * @param int rowIndex - Zeile der betroffenen Zelle
     * @param int columnIndex - Spalte der betroffenen Zelle 
     * @return bool'scher Wert
     */
    public boolean isCellEditable(int rowIndex, int columnIndex)
    { 
        if(rowIndex == 8 && columnIndex == 1)
            return true;
        else 
            return false; 
    }

    /**
     * liefert den Wert einer bestimmten Zelle
     * @param int rowIndex - Zeile der betroffenen Zelle
     * @param int columnIndex - Spalte der betroffenen Zelle 
     * @return Object - Wert innerhalb der Zelle 
     */
    public Object getValueAt(int rowIndex, int columnIndex)
    {  
        if (columnIndex == 0)
        {
            return datenbasis[rowIndex].getName();
        }
        else 
        {
            return datenbasis[rowIndex].getUmlaufzeit();
        }        
    }

    /**
     * bernimmt einen genderten Wert aus dem JTable in die Datenbasis
     * @param Object aValue - ein Wert beliebigen Typs 
     * @param int rowIndex - Zeile der betroffenen Zelle
     * @param int columnIndex - Spalte der betroffenen Zelle 
     */
    public void setValueAt(Object aValue, int rowIndex, int columnIndex)
    { 
        double neuerWert = (Double) aValue;
        datenbasis[rowIndex].setUmlaufzeit(neuerWert);
    }

    /**
     * meldet einen Listener fr ein TableModelEvent an 
     * @param TableModelEvent der Listener 
     */
    public void addTableModelListener(TableModelListener l)
    { 
        listener = l;
    }

    /**
     * entfernt einen registrierten Listener 
     * @param TableModelListener der zu entfernende Listener
     */
    public void removeTableModelListener(TableModelListener l)
    { 
        listener = null;
    }
    
    /**
     * gibt die Klasse einer bestimmten Spalte zurck
     * @param int der Spaltenindex
     * @return Klassenobjekt
     */
    public Class<?> getColumnClass(int columnIndex)
    {
        if(columnIndex == 0)
            return String.class;
        else 
            return Double.class; 
    }
}
