package JTree_3a;

import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JSplitPane;
import javax.swing.JTree;
import javax.swing.WindowConstants;
import javax.swing.event.TreeSelectionEvent;
import javax.swing.event.TreeSelectionListener;
import javax.swing.tree.DefaultMutableTreeNode;
import javax.swing.tree.DefaultTreeSelectionModel;
import javax.swing.tree.TreePath;
import javax.swing.tree.TreeSelectionModel;

/**
 * Stellt die View der Anwendung 
 * 
 * @author      Florian 
 * @version     Kapitel 13
 */

public class GUI extends JFrame 
{
    public final JTree trvHimmelskoerper; 
    public final JLabel lblAnzeige;
    
    public GUI()
    {        
        // Eine Wurzel anlegen
        DefaultMutableTreeNode root = new DefaultMutableTreeNode("Himmelskrper");
        
        // Wurzel an JTree bergeben 
        trvHimmelskoerper = new JTree(root);
        
        // SelectionModel anlegen und bergeben
        DefaultTreeSelectionModel selection = new DefaultTreeSelectionModel();
        selection.setSelectionMode(TreeSelectionModel.CONTIGUOUS_TREE_SELECTION);
        trvHimmelskoerper.setSelectionModel(selection);
        
        // ActionListener
        trvHimmelskoerper.addTreeSelectionListener
        (
            new TreeSelectionListener()
            {
                @Override
                public void valueChanged(TreeSelectionEvent ev)
                {
                    // erste Selektion abfragen
                    TreePath ersteSelektion = trvHimmelskoerper.getSelectionPath();
                    // oder: das aktuelle Event abfragen
                    // ersteSelektion = ev.getPath();
                    // System.out.println(ev.getPath());
                    // die toString-Reprsentation: 
                    // System.out.println(ersteSelektion);
                    Object letztesElement = ersteSelektion.getLastPathComponent();
                    DefaultMutableTreeNode auswahl = (DefaultMutableTreeNode) letztesElement;
                    if(auswahl.isLeaf())
                    {
                        //System.out.println(ev.getPath());
                        Himmelskoerper himmelskoerper = (Himmelskoerper) auswahl.getUserObject();
                        lblAnzeige.setText(himmelskoerper.getName());
                    }
                    else if(auswahl.isRoot())
                    {
                        lblAnzeige.setText("Ich war eine Coladose");
                    }
                    else 
                    {
                        lblAnzeige.setText("");
                    }
                }
            }
        );
        
        // weitere Knoten erstellen
        erstelleKnoten(root);
                
        //Baum in eine ScrollPane legen
        JScrollPane scrTree = new JScrollPane(trvHimmelskoerper);
        
        // Splitpane anlegen und die ScrollPane mit dem Baum auf die linke Seite legen
        JSplitPane splTree = new JSplitPane();
        
        // Baum links platzieren
        splTree.setLeftComponent(scrTree);
        
        // Panel anlegen
        JPanel pnlAnzeige = new JPanel();
        
        // Panel auf die rechte Seite der SplitPane legen
        splTree.setRightComponent(pnlAnzeige);
        
        // Label-Instanz erzeugen
        lblAnzeige = new JLabel("Ich war eine Coladose");
        
        // Label auf Panel platzieren
        pnlAnzeige.add(lblAnzeige);
        
        // Splitpane auf das Fenster legen
        getContentPane().add(splTree);
        
        setTitle("Demo JTree");
        pack();
        setDefaultCloseOperation(WindowConstants.EXIT_ON_CLOSE);
        setVisible(true);
    }
    
    private void erstelleKnoten(DefaultMutableTreeNode root)
    {
        // Planeten anlegen
        DefaultMutableTreeNode planeten = new DefaultMutableTreeNode("Planeten");        
        root.add(planeten);
        planeten.add(new DefaultMutableTreeNode(new Planet("Merkur")));
        planeten.add(new DefaultMutableTreeNode(new Planet("Venus")));
        planeten.add(new DefaultMutableTreeNode(new Planet("Erde")));
        planeten.add(new DefaultMutableTreeNode(new Planet("Mars")));
        planeten.add(new DefaultMutableTreeNode(new Planet("Jupiter")));
        planeten.add(new DefaultMutableTreeNode(new Planet("Saturn")));
        planeten.add(new DefaultMutableTreeNode(new Planet("Uranus")));
        planeten.add(new DefaultMutableTreeNode(new Planet("Neptun")));
                
        // ein paar Monde anlegen
        DefaultMutableTreeNode monde = new DefaultMutableTreeNode("Monde");        
        root.add(monde);
        monde.add(new DefaultMutableTreeNode(new Mond("Luna", "Erde")));  
        monde.add(new DefaultMutableTreeNode(new Mond("Pan", "Saturn")));  
        monde.add(new DefaultMutableTreeNode(new Mond("Pandora", "Saturn")));  
        monde.add(new DefaultMutableTreeNode(new Mond("Atlas", "Saturn")));  
        monde.add(new DefaultMutableTreeNode(new Mond("Prometheus", "Saturn")));  
        monde.add(new DefaultMutableTreeNode(new Mond("Amalthea", "Jupiter")));  
        monde.add(new DefaultMutableTreeNode(new Mond("Thebe", "Jupiter")));  
        monde.add(new DefaultMutableTreeNode(new Mond("Europa", "Jupiter")));  
    }
}
