
/**
 * Die Klasse Mensch modelliert gemeinsame Datenfelder und Methoden eines Menschen
 * 
 * @author      Florian 
 * @version     Kapitel 9
 */
public class Mensch
{
    /**
     * Der Name des Menschen
     */
    private String name = new String();
    /**
     * Der Partner des Menschen
     */
    private Mensch partner = null; 

    /**
     * Der Konstruktor nimmt den Namen des Menschen entgegen und 
     * initialisiert das Feld name damit
     * @param name Name des Menschen
     */
    protected Mensch(String name)
    {
        this.name = name; 
    }

    /**
     * Verheiratet einen Menschen
     * @param partner Referenz auf das Partner-Objekt
     */
    protected String heiraten(Mensch partner) throws BigamieException
    {        
        // Vor-Bedingungen 
        if(this == partner)
            throw new SelbstheiratException(this);
        else        
            if((this.partner != null) || (partner.partner != null))
                throw new BigamieException(this, partner);

        // ab hier wird geheiratet
        this.partner = partner;
        partner.partner = this;
        
        // Nach-Bedingungen
        assert this.partner != null && partner.partner == this : "Beim Heiraten ist ein Fehler aufgetreten!";
        
        // Rckgabe generieren
        return this.getName() + " hat " + partner.getName() + " geheiratet";
    }

    /**
     * Lst die Heirat des Menschen auf
     */
    protected void scheiden()
    {
        if(partner != null)
        {
            String tempName = partner.getName();
            partner.partner = null; 
            this.partner = null;
            System.out.println(this.name + " und " + tempName + " sind jetzt geschieden");
        }
        else
        {
            System.out.println(name + " kann sich nicht scheiden lassen, weil er / sie nicht verheiratet ist.");
        }
    }

    /**
     * Setzt den Namen des Menschen
     * @param String Der Name des Menschen
     */
    public void setName(String name)
    {
        this.name = name; 
    }

    /**
     * Gibt den Namen des Menschen zurck
     * @return Der Name des Menschen
     */
    public String getName()
    {
        return name;
    }

    /**
     * Gibt einen kurzen Vorstellungstext des Menschen aus
     * @return Ein kurzer Vorstellungstext
     */
    public String vorstellen()
    {
        return "Guten Tag, ich heie " + name + ". ";
    }

    @Override
    public String toString()
    {
        return name + " - " + getClass();
    }

    @Override
    public boolean equals(Object another)
    {
        if(this == another) 
            return true;  

        if(another == null) 
            return false; 

        if(another.getClass() == getClass())     
        {
            Mensch temp = (Mensch)another; 
            if( name.equals(temp.getName()) )
                return true;
        }

        return false;
    }

    @Override
    public int hashCode()
    {
        return name.hashCode();
    }
}
