
/**
 * Die Klasse DemoSetComparator fhrt die Verwendung der Schnittstelle Comparator innerhalb einer List vor
 * 
 * @author      Florian 
 * @version     Kapitel 15
 */
import java.util.*;

public class DemoListComparator
{ 
    public static class BezeichnungComparator implements Comparator<Bier>
    {
        public int compare(Bier bier_1, Bier bier_2)
        {
            return bier_1.bezeichnung.compareTo(bier_2.bezeichnung);
        }
    }
    
    public static class HerkunftComparator implements Comparator<Bier>
    {
        public int compare(Bier bier_1, Bier bier_2)
        {
            return bier_1.herkunft.compareTo(bier_2.herkunft);
        }
    }

    public static class Bier
    {
        private int produktnummer;
        private String bezeichnung;
        private String herkunft;
        
        public Bier(int produktnummer, String bezeichnung, String herkunft)
        {
            this.produktnummer = produktnummer;
            this.bezeichnung = bezeichnung; 
            this.herkunft = herkunft;
        }
 
        @Override
        public int hashCode()
        {
            System.out.println("Jetzt wird die hashCode-Methode aufgerufen");
            return produktnummer * (bezeichnung.hashCode() + herkunft.hashCode());
        }
        
        @Override
        public boolean equals(Object obj) 
        {    
            System.out.println("Jetzt wird die equals-Methode aufgerufen");
            if (this == obj)
            {
                return true;
            }
            
            if (obj == null)
            {
                return false;
            }
            
            if (this.getClass() != obj.getClass())
            {
                return false;
            }    
            
            Bier temp = (Bier) obj;  
            return
                produktnummer == temp.produktnummer && 
                bezeichnung.equalsIgnoreCase(temp.bezeichnung) &&
                herkunft.equalsIgnoreCase(temp.herkunft);
        }
        
        @Override
        public String toString()
        {
            return produktnummer + ", " + bezeichnung + " aus " + herkunft;
        }
    }
    
    public static void main(String[] args)
    {  
        List<Bier> angebot = new ArrayList<>(); 
        angebot.add(new Bier(4711, "Flensburger", "Flensburg"));
        angebot.add(new Bier(4712, "Rothaus-Pils", "Grafenhausen (Groherzogtum Baden)"));
        angebot.add(new Bier(4713, "Franziskaner", "Mnchen (Freistaat Bayern)"));
        angebot.add(new Bier(4714, "Augustiner", "Mnchen (Freistaat Bayern)"));
        angebot.add(new Bier(4715, "Dominikaner Bru", "Lekkerland")); 
        angebot.add(new Bier(4715, "Dominikaner Bru", "Lekkerland")); 
     
        HerkunftComparator herkComparator = new HerkunftComparator();
        Collections.sort(angebot, herkComparator);
        
        System.out.println("\nMit der for-each-Schleife iterieren - nach Herkunft sortiert:");
        // mit der for-each-Schleife iterieren
        for(Bier bier: angebot)
        {
            // ausgegeben wird die Rckgabe der toString-Methode
            System.out.println(bier);
        } 
        
        BezeichnungComparator bezComparator = new BezeichnungComparator();
        Collections.sort(angebot, bezComparator);
        
        // Iterator-Objekt
        System.out.println("\nMit einem Iterator-Objekt - nach Bezeichnung sortiert:");
        Iterator it = angebot.iterator();
        while(it.hasNext())
        {
            System.out.println(it.next());
        }
    }
}
