
/**
 * Die Klasse DemoMap demonstriert die Verwendung einer Map - konkrete Implementierung: eine HashMap
 * 
 * @author      Florian 
 * @version     Kapitel 15
 */
import java.util.*;

public class DemoMap
{  
    public static class Bier  
    {
        private int produktnummer;
        private String bezeichnung;
        private String herkunft;
        
        public Bier(int produktnummer, String bezeichnung, String herkunft)
        {
            this.produktnummer = produktnummer;
            this.bezeichnung = bezeichnung; 
            this.herkunft = herkunft;
        } 
        
        @Override
        public int hashCode()
        {
            System.out.println("Jetzt wird die hashCode-Methode aufgerufen");
            return produktnummer * (bezeichnung.hashCode() + herkunft.hashCode());
        }
        
        @Override
        public boolean equals(Object obj)
        {    
            System.out.println("Jetzt wird die equals-Methode aufgerufen");
            if (this == obj)
            {
                return true;
            }
            
            if (obj == null)
            {
                return false;
            }
            
            if (this.getClass() != obj.getClass())
            {
                return false;
            }    
            
            Bier temp = (Bier) obj;  
            return
                produktnummer == temp.produktnummer && 
                bezeichnung.equalsIgnoreCase(temp.bezeichnung) &&
                herkunft.equalsIgnoreCase(temp.herkunft);
        }
        
        @Override
        public String toString()
        {
            return produktnummer + ", " + bezeichnung;
        }
    }
        
    public static void main(String[] args)
    {
        Map<Integer, Bier> waren = new HashMap<>();
        
        System.out.println(waren.put(20, new Bier(4715, "Dominikaner Bru", "Lekkerland")));
        System.out.println(waren.put(10, new Bier(4711, "Augustiner", "Mnchen (Freistaat Bayern)"))); 
        System.out.println(waren.put(50, new Bier(4713, "Flensburger", "Schleswig-Holstein")));
        System.out.println(waren.put(30, new Bier(4713, "Flensburger", "Schleswig-Holstein")));
        System.out.println(waren.put(50, new Bier(4712, "Franziskaner", "Mnchen (Freistaat Bayern)")));
        System.out.println(waren.put(40, new Bier(4714, "Rothaus-Pils", "Grafenhausen (Groherzogtum Baden)")));
                  
        // Iterieren: 
        // 1. mit dem KeySet       
        System.out.println("\nMit dem KeySet iterieren");        
        Set<Integer> schluessel = waren.keySet();
        Iterator<Integer> itSchluessel = schluessel.iterator();
        while(itSchluessel.hasNext())
        {
            Integer temp = itSchluessel.next();
            System.out.println(temp);
        }
        
        // 2. mit der Collection, die die Values enthlt
        System.out.println("\nMit den Values iterieren");
        Collection<Bier> werte = waren.values();
        Iterator<Bier> itWerte = werte.iterator();
        while(itWerte.hasNext())
        {
            Bier temp = (Bier)itWerte.next();
            System.out.println(temp);
        }
        
        // 3. mit dem EntrySet
        System.out.println("\nMit dem EntrySet iterieren");     
        Set<Map.Entry<Integer, Bier>> entries = waren.entrySet();
        Iterator<Map.Entry<Integer, Bier>> itEntries = entries.iterator();
        while(itEntries.hasNext())
        { 
            Map.Entry<Integer, Bier> einEntry = itEntries.next();
            Integer id = einEntry.getKey();
            Bier bier = einEntry.getValue();
            System.out.println(id + " ===> " + bier);
        }
    }
}
