
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.OutputStream;
import java.nio.file.FileSystems;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;

/**
 * Die Klasse enthlt statische Methoden, mit denen das Adressbuch verwaltet werden kann
 * 
 * @author      Florian
 * @version     Kapitel 17
 */
public class Verwaltung
{
    private static String trenner;

    static
    {
        trenner = FileSystems.getDefault().getSeparator();
    }
    private static Adressbuch adressbuch;
    private static String dateiname = System.getProperty("user.home") + trenner + "adressbuch.ser";
    private static Path file = Paths.get(dateiname);

    /**
     * legt ein neues Adressbuch an
     */
    public static void anlegenAdressbuch()
    {
        adressbuch = new Adressbuch();
    }

    /**
     * schreibt einen neuen Eintrag in das Adressbuch
     * @param name Der Name des Freundes 
     * @param email Die Email-Adresse des Freundes
     */
    public static void anlegenFreund(String name, String email)
    {
        if (adressbuch != null)
        {
            adressbuch.addEintrag(name, email);
        }
        else
        {
            throw new RuntimeException("Erstellen Sie erst ein Adressbuch, bevor Sie einen Freund anlegen.");
        }
    }

    /**
     * gibt Auskunft ber das Adressbuch
     */
    public static String getData()
    {
        return adressbuch.toString();
    }

    /**
     * serialisiert das Adressbuch
     */
    public static void serialisiereAdressbuch()
    {
        if (!Files.exists(file))
        {
            try
            {
                Files.createFile(file);
            }
            catch (Exception ex)
            {
                System.out.println(ex);
            }
        }

        try (
                OutputStream os = Files.newOutputStream(file);
                ObjectOutputStream oos = new ObjectOutputStream(os))
        {
            oos.writeObject(adressbuch);
        }
        catch (Exception ex)
        {
            System.out.println(ex);
        }
    }

    /**
     * deserialisiert das Adressbuch
     */
    public static void deserialisiereAdressbuch()
    {
        try (
                InputStream in = Files.newInputStream(file);
                ObjectInputStream deSer = new ObjectInputStream(in))
        {
            // ein Objekt lesen
            Object adressbuch_deserialisiert = deSer.readObject();
            adressbuch = (Adressbuch) adressbuch_deserialisiert;
        }
        catch (ClassNotFoundException | IOException ex)
        {
            System.out.println("Fehler bei Deserialisieren: " + ex);
        }
    }
}
