
import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.nio.charset.Charset;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;

/**
 * Demonstriert die Verwendung von BufferedReader und BufferedWriter - Java 7
 * 
 * @author      Florian
 * @version     Kapitel 17
 */
public class DemoJava7
{
    public static void main(String[] args)
    {
        String inhalt = new String();

        // Daten von der Tastatur einlesen
        try (
                InputStream is = System.in;
                InputStreamReader isr = new InputStreamReader(is);
                BufferedReader br = new BufferedReader(isr))
        {
            System.out.println("Bitte geben Sie Text ein: ");
            String eingabe = new String();
            while ((eingabe = br.readLine()) != null)
            {
                inhalt += eingabe + "\n";
            }
        }
        catch (IOException ex)
        {
            System.out.println(ex.getMessage());
        }

        Path datei = Paths.get("Eingaben.txt");
        Charset zeichensatz = Charset.forName("UTF-8");
        
        // Daten in Datei schreiben
        try (BufferedWriter writer = Files.newBufferedWriter(datei, zeichensatz))
        {
            writer.newLine();
            writer.write("Eingegebener Text: \n");
            writer.write(inhalt);
        }
        catch (IOException ex)
        {
            System.out.println(ex.getMessage());
        }

        // Daten aus Datei lesen und auf Konsole schreiben
        try (BufferedReader reader = Files.newBufferedReader(datei, zeichensatz))
        {
            String zeile = reader.readLine();
            System.out.println(inhalt);
        }
        catch (IOException ex)
        {
            System.out.println(ex.getMessage());
        }
        
        try
        {
            int zeilennummer = 0;
            for (String zeile : Files.readAllLines(datei, zeichensatz))
            {
                System.out.println(++zeilennummer + ": " + zeile);         
            }        
        }
        catch(IOException ex)
        {
            System.out.println(ex);
        }
    }
}
