
/**
 * Demonstriert die Verwendung der Klasse File (vor Java 7)
 * 
 * @author      Florian 
 * @version     Kapitel 17
 */
import java.io.*;
import java.util.Date;

public class DemoFile
{
    public static void main(String[] args)
    {
        // Datei Test.txt relativ zur aktuellen Position 
        File datei_1 = new File("Test.txt");
        // Datei Text.txt mit absoluter Pfad-Angabe: 
        File datei_2 = new File("c:\\Test\\Test.txt");        
        // Datei Daten.txt im Verzeichnis c:\Test\ 
        File datei_3 = new File("c:\\Test", "Daten.txt");
        // Unter Windows auch mglich, statt zwei Backslash ein Slash:
        File datei_4 = new File("c:/Test", "Daten.txt");
        
        if(datei_1.exists())
        {
            System.out.println("Datei existiert!");
        }
        else
        {
            System.out.println("Datei existiert nicht!");
        }
        
        try
        {
            if(datei_1.createNewFile())
            {
                System.out.println("Datei wurde angelegt");
            }
            else 
            {
                System.out.println("Datei wurde nicht angelegt - vermutlich existiert sie bereits");                
            }
        }
        catch(IOException ex)
        {
            System.out.println(ex.getMessage());
        }
        
        // Informationen, die abgefragt werden knnen: 
        if(datei_1.canRead())
            System.out.println("Datei kann gelesen werden");
        if(datei_1.canWrite())
            System.out.println("Datei ist beschreibbar");
        if(datei_1.isDirectory())
            System.out.println("Objekt ist ein Verzeichnis");
        if(datei_1.isFile())
            System.out.println("Objekt ist eine Datei");
        if(datei_1.isHidden())
            System.out.println("Objekt ist versteckt - hidden-Attribut gesetzt");
        if(datei_1.isFile())
            System.out.println("Lnge der Datei: " + datei_1.length());
        long aenderung = datei_1.lastModified();
        Date datum = new Date(aenderung);    
        System.out.println("Letztes nderungsdatum: " + datum);
        
        // File-Objekt anlegen, das eine neue Datei reprsentiert
        File datei_5 = new File("temp.txt");
        // ursprngliche Datei umbenennen
        datei_1.renameTo(datei_5);
        // umbenannte Datei lschen
        datei_5.delete();
        
        // zum weiterarbeiten Datei erneut anlegen: 
        try
        {
            if(datei_1.createNewFile())
            {
                System.out.println("Datei wurde erneut angelegt");
            }
            else 
            {
                System.out.println("Datei wurde nicht angelegt - vermutlich existiert sie bereits");                
            }
        }
        catch(IOException ex)
        {
            System.out.println(ex.getMessage());
        }
        
        // nderungsdatum verndern und zru Kontrolle ausgeben lassen
        if(datei_1.setLastModified(0))
            System.out.println("Datum gendert");
        aenderung = datei_1.lastModified();
        datum = new Date(aenderung);    
        System.out.println("Letztes nderungsdatum: " + datum);
        
        // Datei auf ReadOnly setzen
        if(datei_1.setReadOnly())
            System.out.println("Datei kann jetzt nur gelesen werden");            
        // kontroll-Abfrage
        if(datei_1.canWrite())
            System.out.println("Datei ist beschreibbar - Fehler!");
            
        // Die Arbeit mit Verzeichnissen
        File dir_1 = new File("c:\\temp");
        dir_1.mkdir();
        String pfad = "c:\\temp\\Beispiele\\BlueJ\\Programmierung";
        File dir_2 = new File(pfad);
        dir_2.mkdirs();
        
        File dir_3 = new File("c:/windows");
        // alle Eintrge auslesen (listFiles) und auf Konsole drucken
        File[] fileArray = dir_3.listFiles();
        System.out.println("\n" + fileArray.length + " Eintrge");
        for(File datei: fileArray)
        {
            System.out.print(datei.getName());
            if(datei.isFile())
                System.out.println(" <FILE> ");
            else
                System.out.println(" <DIR> ");
        }
        
        // oder:
        String[] stringArray = dir_3.list();
        System.out.println("\n" + stringArray.length + " Eintrge");
        for(String datei: stringArray)
        {
            System.out.println(datei);
        }
    }
}
