
/**
 * Demonstriert die Arbeit mit den Klassen Path, Files und FileSystem
 * 
 * @author      Florian 
 * @version     Kapitel 17
 */
import java.io.IOException;
import java.nio.file.FileSystem;
import java.nio.file.FileSystems;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
 
public class DemoPath
{
    // Filesystem ermitteln
    private static FileSystem fs = FileSystems.getDefault();

    public static void main(String[] args)
    {
        // Informatioonen hierber abfragen
        System.out.println("Mein Dateisystem: " + fs);
        System.out.println("Trenner: " + fs.getSeparator());
        System.out.println("Dateisystem ist readOnly: " + fs.isReadOnly());

        Iterable<Path> root = fs.getRootDirectories();
        for (Path temp : root)
        {
            System.out.println(temp);
        }

        String kapitel_17 = "C:\\Dropbox\\Kapitel\\Teil 4\\17 - Datenstrme\\17 - Datenstrme.odt";
        Path myPath = Paths.get(kapitel_17);
        Path path_alternative = fs.getPath(kapitel_17);
        int anzahl = myPath.getNameCount();
        for (int i = 0; i < anzahl; i++)
        {
            System.out.println("for-Schleife: " + myPath.getName(i));
        }

        for (Path temp : myPath)
        {
            System.out.println("for-each-Schleife: " + temp);
        }

        // Eigenschaften von Path abfragen
        System.out.println(myPath.toString()); // 
        System.out.println(myPath.isAbsolute());
        System.out.println(myPath.getRoot());
        System.out.println(myPath.getParent());
        System.out.println(myPath.getNameCount());
        System.out.println(myPath.getName(myPath.getNameCount() - 1));

        // NIO-Path in herkoemmliches java.io.File umwandeln:
        java.io.File oldFile = myPath.toFile();
        System.out.println("Ist ein Verzeichnis: " + oldFile.isDirectory());
        System.out.println("Ist eine Datei: " + oldFile.isFile());

        // Verzeichnis anlegen
        myPath = erzeugeVerzeichnis("Lieder");
        // Datei anlegen
        Path datei = erzeugeDatei(myPath, "Texte.txt");

        // versuchen, das Verzeichnis zu loeschen (sollte scheitern, weil nicht leer)
        loesche(myPath);

        // Datei loeschen
        // loesche(datei);

        // Pfad sollte jetzt geloescht werden koennen: 
        // loesche(myPath);
    }
    
    private static Path erzeugeVerzeichnis(String unterverzeichnis)
    {
        Path tempPath = Paths.get(System.getProperty("user.home"));
        tempPath = tempPath.resolve(unterverzeichnis);
        try
        {
            Files.createDirectory(tempPath);
        }
        catch (IOException ex)
        {
            System.out.println("Fehler beim Anlegen des Verzeichnisses: " + ex.getMessage());
        }
        return tempPath;
    }

    private static Path erzeugeDatei(Path verzeichnis, String dateiname)
    {
        Path tempDatei = verzeichnis;
        tempDatei = tempDatei.resolve(Paths.get(dateiname));
        try
        {
            Path datei = Files.createFile(tempDatei);
        }
        catch (IOException ex)
        {
            System.out.println("Fehler beim Anlegen der Datei: " + ex.getMessage());
        }
        return tempDatei;
    }

    private static void loesche(Path pfad)
    {
        try
        {
            Files.delete(pfad);
        }
        catch (IOException ex)
        {
            System.out.println("Fehler beim Lschen von \"" + pfad + "\":\n" + ex.getMessage());
        }
    }
}
