
import java.io.IOException;
import java.nio.file.DirectoryStream;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.attribute.BasicFileAttributes;
import java.util.ArrayList;
import javax.swing.table.AbstractTableModel;

/**
 * Das Tabellenmodell fr die Anzeige der Dateien und ihrer Attribute
 * 
 * @author Florian
 */
class Attribute extends AbstractTableModel
{
    /**
     * Datenbasis
     */
    private ArrayList<Path> files = new ArrayList<>();
    /**
     * Spaltenueberschriften
     */
    private String[] headers = new String[]
    {
        "Name", "Erstellungsdatum", "Gre in MB"
    };

    Attribute(Path wurzel)
    {
        try
        {
            DirectoryStream<Path> dateien = Files.newDirectoryStream(wurzel);
            for (Path temp : dateien)
            {
                if (!Files.isDirectory(temp))
                {
                    files.add(temp);
                }
            }
        }
        catch (IOException ex)
        {
            System.out.println("Konstruktor Tabellenmodell: " + ex);
        }
    }
    
    public Path getPathAt(int i)
    {
        return files.get(i);
    }

    public int getRowCount()
    {
        return files.size();
    }

    public int getColumnCount()
    {
        return headers.length;
    }

    public Object getValueAt(int rowIndex, int columnIndex)
    {
        try
        {
            Path temp = files.get(rowIndex);
            BasicFileAttributes attrib = Files.readAttributes(temp, BasicFileAttributes.class);
            switch (columnIndex)
            {
                case 0:
                    return temp.getFileName();
                case 1:
                    return attrib.creationTime();
                default:
                    return attrib.size() / 1048576.0 ;
            }
        }
        catch (IOException ex)
        {
            System.out.println("Tabellenmodell, getValueAt: " + ex);
            return null;
        }
    }

    @Override
    public String getColumnName(int columnIndex)
    {
        return headers[columnIndex];
    }
}
