
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.io.IOException;
import java.nio.charset.Charset;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.attribute.BasicFileAttributes;
import java.util.List;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.swing.event.TreeSelectionEvent;
import javax.swing.event.TreeSelectionListener;

/**
 * Controllerklasse des Projektes
 * 
 * @author      Florian 
 * @version     Kapitel 17
 */
public class Controller extends MouseAdapter implements TreeSelectionListener
{
    /**
     * Model fuer den Baum 
     */
    private Dateisystem modelTree;
    /**
     * View des Projektes
     */
    private GUI view;

    public Controller(Dateisystem model, GUI view)
    {
        this.modelTree = model;
        Path beginn = (Path) model.getRoot();
        view.tblDateiliste.setModel(new Attribute(beginn));
        this.view = view;

        // Model des JTree setzen
        view.trvDateisystem.setModel(model);

        // ActionListener anmelden
        view.trvDateisystem.addTreeSelectionListener(this);

        view.tblDateiliste.addMouseListener(this);
    }

    /**
     * auf Auswahl reagieren
     */
    @Override
    public void valueChanged(TreeSelectionEvent ev)
    {
        // Selektion abfragen
        Path pfad = (Path) view.trvDateisystem.getLastSelectedPathComponent();
        view.ausgebenText(ermittleAttribute(pfad));
        view.tblDateiliste.setModel(new Attribute(pfad));
    }

    private String ermittleAttribute(Path pfad)
    {
        String attribute = new String();
        try
        {
            BasicFileAttributes attrib = Files.readAttributes(pfad, BasicFileAttributes.class);
            attribute += "Ist eine Datei: " + attrib.isRegularFile() + "\n";
            attribute += "Ist ein Verzeichnis: " + attrib.isDirectory() + "\n";
            attribute += "Ist eine Verknpfung: " + attrib.isSymbolicLink() + "\n";
            attribute += "Ist sonstiges: " + attrib.isOther() + "\n";
            attribute += "Letztes nderungsdatum: " + attrib.lastModifiedTime() + "\n";
            attribute += "Letztes Zugriffsdatum: " + attrib.lastAccessTime() + "\n";
            attribute += "Erstellungsdatum: " + attrib.creationTime() + "\n";
            attribute += "Gre " + attrib.size() + "\n";
        }
        catch (IOException ex)
        {
            System.out.println(ex);
        }
        return attribute;
    }

    @Override
    public void mouseClicked(MouseEvent e)
    {
        String result = new String();
        try
        {
            int i = view.tblDateiliste.getSelectedRow();
            Path selection = view.getSelectedTableRow(i);
            String mime = Files.probeContentType(selection);
            result = "MIME-Typ: " + mime + "\n" + ermittleAttribute(selection);
            view.ausgebenText(mime);
            if (mime != null && mime.startsWith("text/"))
            {
                List<String> content = Files.readAllLines(selection, Charset.forName("UTF-8"));
                for (String temp : content)
                {
                    result += temp + "\n";
                }
            }
            else
            {
                result += "Keine Textdatei: " + mime;
            }
        }
        catch (IOException ex)
        {
            System.out.println("mouseClicked" + ex);
        }
        view.ausgebenText(result);
    }
}
