
import java.nio.file.DirectoryStream;
import java.nio.file.Files;
import java.nio.file.Path;
import java.util.ArrayList;
import javax.swing.event.TreeModelListener;
import javax.swing.tree.TreeModel;
import javax.swing.tree.TreePath;

/**
 * Modell des Baumes
 * 
 * @author      Florian 
 * @version     Kapitel 17
 */
public class Dateisystem implements TreeModel
{
    private ArrayList<TreeModelListener> listener = new ArrayList<>();
    private static ArrayList<Path> myParentsChildren = new ArrayList<>();
    private static Path root;

    public Dateisystem(Path root)
    {
        Dateisystem.root = root;
    }

    @Override
    public Object getRoot()
    {
        // System.out.println("getRoot: Returns the root of the tree"); 
        return root;
    }

    @Override
    public Object getChild(Object parent, int index)
    {
        // System.out.println("getChild: Returns the child of parent at index; index in the parent's child array");
        return myParentsChildren.get(index);
    }

    @Override
    public int getChildCount(Object parent)
    {
        // System.out.println("getChildCount: Returns the number of children of parent");
        myParentsChildren = new ArrayList<>();
        Path parentPath = (Path) parent; 
        try (DirectoryStream<Path> childrenOfParent = Files.newDirectoryStream(parentPath))
        {
            for (Path temp : childrenOfParent)
            {
                if (Files.isDirectory(temp))
                {
                    myParentsChildren.add(temp);
                }
            }
            return myParentsChildren.size();
        }
        catch (Exception ex)
        {
            System.out.println("getChildCount: " + ex);
            return 0;
        }
    }

    @Override
    public boolean isLeaf(Object node)
    {
        // System.out.println("isLeaf: Returns true if node is a leaf"); 
        Path temp = (Path) node;
        return !Files.isDirectory(temp);
    }

    @Override
    public int getIndexOfChild(Object parent, Object child)
    {
        // System.out.println("getIndexOfChild: Returns the index of child in parent");
        Path temp = (Path) child;
        for (int i = 0; i < myParentsChildren.size(); i++)
        {
            if (temp == myParentsChildren.get(i))
            {
                return i;
            }
        }
        return -1;
    }

    @Override
    public void valueForPathChanged(TreePath path, Object newValue)
    {
        System.out.println("valueForPathChanged");
    }

    @Override
    public void addTreeModelListener(TreeModelListener l)
    {
        // System.out.println("addTreeModelListener: Adds a listener for the TreeModelEvent posted after the tree changes");
        listener.add(l);
    }

    @Override
    public void removeTreeModelListener(TreeModelListener l)
    {
        // System.out.println("removeTreeModelListener: Removes a listener previously added with addTreeModelListener");
        listener.remove(l);
    }
}
