import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.io.PrintWriter;
import java.net.Socket;

/**
 * Die Klasse Session verarbeitet die Anfrage.
 *
 * @author      Florian
 * @version     Kapitel 18
 */
public class Session implements Runnable
{
    private final Socket socket;

    public Session(Socket socket)
    {
        this.socket = socket;
    }

    public void run()
    {
        try (
                // vom Socket einen InputStream beziehen
                InputStream streamIn = socket.getInputStream();
                // Br?ckenklasse, um vom Byte-Stream zum Character-Stream zu kommen
                InputStreamReader streamReaderIn = new InputStreamReader(streamIn);
                // und mit einem BufferedReader verketten
                BufferedReader reader = new BufferedReader(streamReaderIn);
                // vom Socket einen OutputStream beziehen
                OutputStream streamOut = socket.getOutputStream();
                // mit einem CharacterStream verketten
                PrintWriter writer = new PrintWriter(streamOut, true);)
        { 
            String anfrage = reader.readLine();

            while (anfrage != null)
            {
                try
                {
                    Thread.sleep(2000);
                }
                catch (InterruptedException ex)
                {
                    System.out.println(ex.getMessage());
                }

                // Anfrage mit der String-Methode split() in Tokens - Array of String - zerlegen:
                String[] tokens = anfrage.split(" ");

                // die Zahlen in Integer-Werte umwandeln:
                int x = Integer.parseInt(tokens[1]);
                int y = Integer.parseInt(tokens[2]);

                // Variable, die das Ergebnis aufnehmen wird:
                int ergebnis = 0;

                // In den richtigen Verarbeitungszweig springen: 
                if (tokens[0].equalsIgnoreCase("add"))
                {
                    ergebnis = x + y;
                }
                else
                {
                    if (tokens[0].equals("diff"))
                    {
                        ergebnis = x - y;
                    }
                }

                // Antwort generieren: 
                String antwort = String.valueOf(ergebnis);

                // an Client uebergeben: 
                writer.println(antwort);

                anfrage = reader.readLine();
            }
        }
        catch (IOException ex)
        {
            System.out.println(ex.getMessage());
        }
    }
}
