
import java.io.EOFException;
import java.io.IOException;
import java.io.InputStream;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.OutputStream;
import java.net.Socket;

/**
 * Die Klasse Session verarbeitet die Anfrage. 
 * 
 * @author      Florian 
 * @version     Kapitel 18
 */
public class Session implements Runnable
{
    private final Socket socket;

    public Session(Socket socket)
    {
        this.socket = socket;
    }

    public void run()
    {
        try (
                InputStream streamIn = socket.getInputStream();
                ObjectInputStream objectIn = new ObjectInputStream(streamIn);
                OutputStream streamOut = socket.getOutputStream();
                ObjectOutputStream objectOut = new ObjectOutputStream(streamOut);)
        {

            Aufgabe aufgabe;
            while ((aufgabe = (Aufgabe) objectIn.readObject()) != null)
            {
                try
                {
                    Thread.sleep(2000);
                }
                catch (InterruptedException ex)
                {
                    System.out.println(ex.getMessage());
                }

                if (aufgabe instanceof Rechenaufgabe)
                {
                    if (aufgabe instanceof AddRechenaufgabe)
                    {
                        aufgabe = new AddService().execute(aufgabe);
                    }
                    else
                    {
                        if (aufgabe instanceof DiffRechenaufgabe)
                        {
                            aufgabe = new DiffService().execute(aufgabe);
                        }
                        else
                        {
                            if (aufgabe instanceof DivRechenaufgabe)
                            {
                                aufgabe = new DivService().execute(aufgabe);
                            }
                        }
                    }
                }

                // an Client uebergeben:  
                objectOut.writeObject(aufgabe);
            }
        }
        catch (EOFException ex)
        {
            /*
             * Diese Exception muss nicht behandelt werden; sie sagt nur, dass
             * keine weiteren Daten gekommen sind. 
             */
        }
        catch (IOException | ClassNotFoundException ex)
        {
            // Diese Exceptions werden verarbeitet, wenn auch nur durch eine Konsolenausgabe
            System.out.println(ex.getMessage());
        }
    }
}
