import java.io.EOFException;
import java.io.IOException;
import java.io.InputStream;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.OutputStream;
import java.net.Socket;
import java.util.HashMap;

/**
 * Die Klasse Session verarbeitet die Anfrage. 
 * 
 * @author      Florian 
 * @version     Kapitel 18
 */
public class Session implements Runnable
{
    /**
     * Verbindung zum anfragenden Rechner
     */
    private final Socket socket;
    /**
     * HashMap, die im Key speichert, welche Aufgaben der Server annehmen kann; als Value wird eine Instanz 
     * der jeweiligen Service-Klasse gespeichert. 
     */
    private final HashMap<String, Service> services;

    /**
     * Konstruktor der Klasse - erwartet als Parameter den Socket und die HashMap
     */
    public Session(Socket socket, HashMap<String, Service> services)
    {
        this.socket = socket;
        this.services = services;
    }

    /**
     * Methode, die ausgefuehrt wird, wenn der Thread gestartet wird. 
     */
    public void run()
    {
        try (
                InputStream streamIn = socket.getInputStream();
                ObjectInputStream objectIn = new ObjectInputStream(streamIn);
                OutputStream streamOut = socket.getOutputStream();
                ObjectOutputStream objectOut = new ObjectOutputStream(streamOut);)
        {
            Aufgabe aufgabe;
            while ((aufgabe = (Aufgabe) objectIn.readObject()) != null)
            {
                try
                {
                    Thread.sleep(2000);
                }
                catch (InterruptedException ex)
                {
                    System.out.println(ex.getMessage());
                }

                String klassenname = aufgabe.getClass().getName();
                Service service = services.get(klassenname);

                if (service == null)
                {
                    throw new Exception("Es gibt keinen Service fuer " + klassenname);
                }

                aufgabe = service.execute(aufgabe);

                // an Client bergeben:  
                objectOut.writeObject(aufgabe);
            }
        }
        catch (EOFException ex)
        {
            /*
             * muss nicht behandelt werden; keine weitere Daten mehr
             */
        }
        catch (Exception ex)
        {
            // mglich: IOException | ClassNotFoundException & Exception
            // wird behandelt, wenn auch im Moment nur durch eine Konsolenausgabe
            System.out.println(ex.getMessage());
        }
    }
}
