import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.SQLException;
import java.sql.Statement;
 
/**
 * Demonstriert die Arbeit mit Datenbanken - legt Attribute an
 * 
 * @author      Florian 
 * @version     Kapitel 19
 */ 
public class JDBCDemo_3
{
    public static void main(String args[])
    {
        // URL der Datenbank 
        String url = "jdbc:mysql://localhost:3306/mysql";

        // Treiber laden
        try
        {
            Class.forName("com.mysql.jdbc.Driver");
        }
        catch (ClassNotFoundException ex)
        {
            System.out.println("Der Treiber konnte nicht geladen werden: " + ex.getMessage());
        }

        // Verbindung herstellen 

        try (
                Connection con = DriverManager.getConnection(url);
                Statement stmt = con.createStatement();)
        {
            // SQL-Befehl zum Anlegen einer Datenbank
            String[] befehle = new String[4];

            befehle[0] = "CREATE TABLE Orte(ID INT NOT NULL AUTO_INCREMENT, Treffpunkt VARCHAR(50) NOT NULL, PRIMARY KEY (ID))";
            befehle[1] = "CREATE TABLE Partner(ID INT NOT NULL AUTO_INCREMENT, Partnername VARCHAR(50) NOT NULL, PRIMARY KEY (ID))";
            befehle[2] = "CREATE TABLE Kategorien(ID INT NOT NULL AUTO_INCREMENT, Kategorie VARCHAR(20) NOT NULL, PRIMARY KEY (ID))";
            befehle[3] = "CREATE TABLE Verabredungen(ID INT NOT NULL AUTO_INCREMENT, Datum VARCHAR(20) NOT NULL, PartnerID INT NOT NULL REFERENCES Partner(ID), OrtID INT NOT NULL REFERENCES Ort(ID), KategorieID INT NOT NULL REFERENCES Kategorie(ID), Bemerkung VARCHAR(20), PRIMARY KEY (ID))";

            /*
            befehle[0] = "DROP TABLE Orte";
            befehle[1] = "DROP TABLE Partner";
            befehle[2] = "DROP TABLE Kategorien";
            befehle[3] = "DROP TABLE Verabredungen";            
             */

            // Autocommit ausschalten
            con.setAutoCommit(false);

            try
            {
                // Befehl absetzen
                for (String befehl : befehle)
                {
                    stmt.executeUpdate(befehl);
                    System.out.println("Tabelle angelegt mit Befehl: " + befehl);
                }

                // bergebene Befehle ausfhren
                con.commit();
                System.out.println("ordnungsgem abgeschlossen");
            }
            catch (SQLException ex)
            {
                System.out.println(ex.getMessage());
                con.rollback();
            }

            // Autocommit wieder einschalten
            con.setAutoCommit(true);
        }
        catch (SQLException ex)
        {
            ex.printStackTrace();
        }
    }
}
