
import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.SQLException;
import java.sql.Statement;

/**
 * Demonstriert die Arbeit mit Datenbanken - fgt Werte in die Tabellen ein
 * 
 * @author      Florian 
 * @version     Kapitel 19
 */
public class JDBCDemo_4
{
    public static void main(String args[])
    {
        // URL der Datenbank 
        String url = "jdbc:mysql://localhost:3306/mysql";

        // Treiber laden
        try
        {
            Class.forName("com.mysql.jdbc.Driver");
        }
        catch (ClassNotFoundException ex)
        {
            System.out.println("Der Treiber konnte nicht geladen werden: " + ex.getMessage());
        }

        try (Connection con = DriverManager.getConnection(url);
                Statement stmt = con.createStatement();)
        {

            // SQL-Befehl zum Anlegen einer Datenbank
            String[] befehle = new String[19];

            /* damit werden smtliche Daten gelscht:
            befehle = new String[4];
            befehle[0] = "DELETE FROM Partner";
            befehle[1] = "DELETE FROM Orte";
            befehle[2] = "DELETE FROM Kategorien";
            befehle[3] = "DELETE FROM Verabredungen"; 
             */

            // Kategorien
            befehle[0] = "INSERT INTO Kategorien (Kategorie) VALUES ('privat')";
            befehle[1] = "INSERT INTO Kategorien (Kategorie) VALUES ('dienstlich')";

            // Orte
            befehle[2] = "INSERT INTO Orte (Treffpunkt) VALUES ('Cafe Bohne')";
            befehle[3] = "INSERT INTO Orte (Treffpunkt) VALUES ('Cafe Tasse')";
            befehle[4] = "INSERT INTO Orte (Treffpunkt) VALUES ('Besprechungsraum')";
            befehle[5] = "INSERT INTO Orte (Treffpunkt) VALUES ('Alter Rittersaal')";

            // Partner
            befehle[6] = "INSERT INTO Partner (Partnername) VALUES ('Heinz B.')";
            befehle[7] = "INSERT INTO Partner (Partnername) VALUES ('Hilde B.')";
            befehle[8] = "INSERT INTO Partner (Partnername) VALUES ('Stefan B.')";
            befehle[9] = "INSERT INTO Partner (Partnername) VALUES ('Michael M.')";
            befehle[10] = "INSERT INTO Partner (Partnername) VALUES ('Dieter H.')";
            befehle[11] = "INSERT INTO Partner (Partnername) VALUES ('Bernd S.')";

            // Verabredungen
            befehle[12] = "INSERT INTO Verabredungen(Datum, PartnerID, OrtID, KategorieID, Bemerkung) VALUES ('1. Juli', 1, 2, 2, 'Karte mitbringen')";
            befehle[13] = "INSERT INTO Verabredungen(Datum, PartnerID, OrtID, KategorieID) VALUES ('2. Juli', 2, 4, 2)";
            befehle[14] = "INSERT INTO Verabredungen(Datum, PartnerID, OrtID, KategorieID, Bemerkung) VALUES ('5. Juli', 3, 2, 2, 'bloss nicht vergessen')";
            befehle[15] = "INSERT INTO Verabredungen(Datum, PartnerID, OrtID, KategorieID, Bemerkung) VALUES ('10. Juli', 4, 2, 2, 'Wein kaufen')";
            befehle[16] = "INSERT INTO Verabredungen(Datum, PartnerID, OrtID, KategorieID) VALUES ('30. Juli', 5, 3, 1)";
            befehle[17] = "INSERT INTO Verabredungen(Datum, PartnerID, OrtID, KategorieID, Bemerkung) VALUES ('15. Juli', 6, 1, 2, 'Stammtisch')";
            befehle[18] = "INSERT INTO Verabredungen(Datum, PartnerID, OrtID, KategorieID, Bemerkung) VALUES ('29. Juli', 3, 4, 1, 'KEGELN!!!')";
 
            // Autocommit ausschalten
            con.setAutoCommit(false);

            try
            {
                // Befehl absetzen
                for (String befehl : befehle)
                {
                    stmt.executeUpdate(befehl);
                    System.out.println("Werte eingetragen mit Befehl: " + befehl);
                }

                // Befehle ausfhren
                con.commit();
                System.out.println("ordnungsgem abgeschlossen");
            }
            catch (SQLException ex)
            {
                System.out.println(ex.getMessage());
                con.rollback();
            }
        }
        catch (SQLException ex)
        {
            ex.printStackTrace();
        }
    }
}
