import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.ResultSet;
import java.sql.ResultSetMetaData;
import java.sql.SQLException;
import java.sql.Statement;

/**
 * Demonstriert die Arbeit mit Datenbanken - zeigt die Werte in der Datenbank an
 * 
 * @author      Florian 
 * @version     Kapitel 19
 */
public class JDBCDemo_5
{
    public static void main(String args[])
    {
        // URL der Datenbank 
        String url = "jdbc:mysql://localhost:3306/mysql";

        // Treiber laden
        try
        {
            Class.forName("com.mysql.jdbc.Driver");
        }
        catch (ClassNotFoundException ex)
        {
            System.out.println("Der Treiber konnte nicht geladen werden: " + ex.getMessage());
        }

        try (
                Connection con = DriverManager.getConnection(url);
                Statement stmt = con.createStatement();)
        {
            String[] befehle = new String[2];
            befehle[0] = "SELECT ID, Partnername FROM Partner";
            befehle[1] = "SELECT * FROM Verabredungen";

            try (ResultSet daten = stmt.executeQuery(befehle[0]);)
            {
                while (daten.next())
                {
                    int id = daten.getInt("ID");
                    // oder: int id = daten.getInt(1);

                    String name = daten.getString("Partnername");
                    // oder: String name = daten.getString(2); 

                    //Ausgabe: 
                    System.out.println(id + " => " + name);
                }
            }
            catch (SQLException ex)
            {
                System.out.println(ex.getMessage());
            }

            try (ResultSet daten = stmt.executeQuery(befehle[1]);)
            {
                ResultSetMetaData meta = daten.getMetaData();
                int spaltenZahl = meta.getColumnCount();
                String[] attribute = new String[spaltenZahl];

                for (int i = 0; i < spaltenZahl; i++)
                {
                    attribute[i] = meta.getColumnLabel(i + 1);
                }

                int zaehler = 0;
                while (daten.next())
                {
                    zaehler++;
                    System.out.println(zaehler + ". Verabredung: ");

                    for (int i = 0; i < spaltenZahl; i++)
                    {
                        System.out.print("\t" + attribute[i] + ": " + daten.getString(i + 1) + "\t");
                    }
                    System.out.println();
                }
            }
        }
        catch (SQLException ex)
        {
            ex.printStackTrace();
        }
    }
}