
/**
 * Datenbasis - das Modell - fr die Tabelle
 * 
 * @author      Florian
 * @version     Kapitel 15
 */
import java.util.*;
import java.awt.Color;
import javax.swing.table.*;
import javax.swing.event.TableModelListener;

public class Planetenverwaltung extends AbstractTableModel
{
    private Planet pluto = new Planet("Pluto", 90800, true);

    static class MyPlanetRenderer extends DefaultTableCellRenderer
    {
        @Override
        public void setValue(Object value)
        {
            boolean temp = (Boolean) value;
            if(temp)
            {
                setForeground(Color.GREEN);
                setText("Ja");
            }
            else 
            {
                setForeground(Color.RED);
                setText("Nein");
            }
        }
    } 
    
    /**
     * Die Datenbasis - eine ArrayList, das die neun Planeten speichert
     */
    private ArrayList<Planet> datenbasis = new ArrayList<>();
    
    public Planetenverwaltung()
    {
        datenbasis.add(new Planet("Merkur", 87.99, true));
        datenbasis.add(new Planet("Venus", 224.7, true) );
        datenbasis.add(new Planet("Erde", 365.2, true) );
        datenbasis.add(new Planet("Mars", 687, true));
        datenbasis.add(new Planet("Jupiter", 4332, true));
        datenbasis.add(new Planet("Saturn", 10760, true) );
        datenbasis.add(new Planet("Uranus", 30680, true) );
        datenbasis.add(new Planet("Neptun", 59900, true) );
        datenbasis.add(pluto); 
    }
    
    /**
     * Sortiert die Datenbasis gem dem bergebenen Comparator
     * @param comp Der gewnschte Comparator
     */
    public void setSort(Comparator comp)
    {
        Collections.sort(datenbasis, comp);
    }
    
    /**
     * Listener fr nderungen an der Datenbasis
     */
    private TableModelListener listener = null;

    /**
     * lscht Pluto aus der Liste der Planeten
     */
    public void loeschePluto()
    { 
        datenbasis.remove(pluto);
        this.fireTableDataChanged();
    }
    
    /**
     * gibt die Klasse einer bestimmten Spalte zurck
     * @param int der Spaltenindex
     * @return Klassenobjekt
     */
    @Override
    public Class<?> getColumnClass(int columnIndex)
    {
        if(columnIndex == 0)
            return String.class;
        else if(columnIndex == 1)
            return Double.class; 
        else  
            return Boolean.class; 
    }
    
    
    /**
     * Gibt die Anzahl der Datenstze - Zeilen - zurck
     * @return int - Anzahl der Zeilen
     */
    @Override
    public int getRowCount()
    { 
        return datenbasis.size();
    }

    /**
     * Gibt die Anzahl der Spalten zurck
     * @return int - Anzahl der Spalten
     */
    @Override
    public int getColumnCount()
    { 
        return 3;
    }

    /**
     * gibt die berschrift einer bestimmten Spalten zurck
     * @param int die gesuchte Spalte
     * @return String - Name der berschrift
     */
    @Override
    public String getColumnName(int columnIndex)
    { 
        switch(columnIndex)
        {
            case 0:     return "Planet"; 
            case 1:     return "Umlaufzeit";
            default:    return "ist ein Planet";            
        }
    }

    /**
     * liefert den Wert einer bestimmten Zelle
     * @param int rowIndex - Zeile der betroffenen Zelle
     * @param int columnIndex - Spalte der betroffenen Zelle 
     * @return Object - Wert innerhalb der Zelle 
     */
    @Override
    public Object getValueAt(int rowIndex, int columnIndex)
    {  
        if (columnIndex == 0)
        {
            return datenbasis.get(rowIndex).getName();
        }
        else if(columnIndex == 1)
        {
            return datenbasis.get(rowIndex).getUmlaufzeit();
        }      
        else 
        {
            return datenbasis.get(rowIndex).isPlanet();
        }
    }
}
